@@ -19,7 +19,6 @@ sub prepare {
             ($opcode, $body)= $dbh->{cass_connection}->request(
                 OPCODE_PREPARE,
                 pack_longstring($statement),
-                NO_RETRY,
             );
             1;
         } or do {
@@ -63,7 +62,7 @@ sub prepare {
     }
     $sth->{cass_params}= [];
     $sth->{cass_consistency}= $attribs->{consistency} // $attribs->{Consistency} // $dbh->{cass_consistency} // 'one';
-    $sth->{cass_retry_count}= $attribs->{retries} // $attribs->{Retries} // NO_RETRY;
+    $sth->{cass_async}= $attribs->{async};
     $sth->{cass_paging}= $attribs->{perpage} // $attribs->{PerPage} // $attribs->{per_page};
     return $outer;
 }
@@ -136,7 +135,7 @@ sub ping {
 
     eval {
         my $conn= $dbh->{cass_connection};
-        my ($opcode)= $conn->request(OPCODE_OPTIONS, '', NO_RETRY);
+        my ($opcode)= $conn->request(OPCODE_OPTIONS, '');
         die unless $opcode == OPCODE_SUPPORTED;
         1;
     } or do {
